@@ -30,6 +30,10 @@ class RichTextComposerControler;
 class RichTextComposerActions;
 class RichTextExternalComposer;
 class RichTextComposerEmailQuoteHighlighter;
+/**
+ * @brief The RichTextComposer class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KPIMTEXTEDIT_EXPORT RichTextComposer : public KPIMTextEdit::RichTextEditor
 {
     Q_OBJECT
@@ -99,14 +103,14 @@ public:
     const QString defaultQuoteSign() const;
     void createActions(KActionCollection *ac);
 
-    QList<QAction *> richTextActionList() const;
+    QVector<QAction *> richTextActionList() const;
     void setEnableActions(bool state);
 
     KPIMTextEdit::RichTextComposerControler *composerControler() const;
     KPIMTextEdit::RichTextExternalComposer *externalComposer() const;
     KPIMTextEdit::RichTextComposerActions *composerActions() const;
     void createHighlighter() override;
-    virtual bool processAutoCorrection(QKeyEvent *event);
+    virtual bool processModifyText(QKeyEvent *event);
 
 public Q_SLOTS:
     void insertPlainTextImplementation();
