@@ -77,11 +77,11 @@ void RichTextComposerEmailQuoteHighlighter::toggleSpellHighlighting(bool on)
 void RichTextComposerEmailQuoteHighlighter::highlightBlock(const QString &text)
 {
     QString simplified = text;
-    simplified = simplified.remove(QRegularExpression(QStringLiteral("\\s"))).
-                 replace(QLatin1Char('|'), QLatin1Char('>'));
+    simplified.remove(QRegularExpression(QStringLiteral("\\s"))).
+    replace(QLatin1Char('|'), QLatin1Char('>'));
 
     while (simplified.startsWith(QLatin1String(">>>>"))) {
-        simplified = simplified.mid(3);
+        simplified.remove(0, 3);
     }
 
     if (simplified.startsWith(QLatin1String(">>>"))) {
