@@ -65,8 +65,3 @@ EmoticonTextEditAction::~EmoticonTextEditAction()
 {
     delete d;
 }
-
-void EmoticonTextEditAction::setEmojiPlainText(bool b)
-{
-    d->selector->setEmojiPlainText(b);
-}
