@@ -21,10 +21,8 @@
 #ifndef KPIMTEXTEDIT_EMOTICONTEXTEDITSELECTOR_H
 #define KPIMTEXTEDIT_EMOTICONTEXTEDITSELECTOR_H
 
-#include <QListWidgetItem>
 #include <QWidget>
 namespace KPIMTextEdit {
-class EmoticonListWidgetSelector;
 class EmoticonUnicodeTab;
 class EmoticonTextEditSelector : public QWidget
 {
@@ -33,9 +31,6 @@ public:
     explicit EmoticonTextEditSelector(QWidget *parent = nullptr);
     ~EmoticonTextEditSelector();
 
-    Q_REQUIRED_RESULT bool emojiPlainText() const;
-    void setEmojiPlainText(bool emojiPlainText);
-
 public Q_SLOTS:
     void loadEmoticons();
 
