@@ -22,9 +22,14 @@
 
 #include <QTabWidget>
 
+#include "emoticonunicodeutils.h"
 #include "kpimtextedit_export.h"
 
 namespace KPIMTextEdit {
+/**
+ * @brief The EmoticonUnicodeTab class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KPIMTEXTEDIT_EXPORT EmoticonUnicodeTab : public QTabWidget
 {
     Q_OBJECT
@@ -38,8 +43,7 @@ Q_SIGNALS:
     void itemSelected(const QString &);
 
 private:
-    void createPlainTextEmoticonTab(const QString &str, const QList<uint> &emoticons);
-    void createPlainTextEmoticonTab(const QString &str, const QStringList &emoticons);
+    void createPlainTextEmoticonTab(const QString &str, const QVector<EmoticonUnicodeUtils::EmoticonStruct> &emoticons);
 };
 }
 
