@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -20,8 +20,6 @@
 #ifndef KPIMTEXTEDIT_INSERTIMAGEWIDGET_H
 #define KPIMTEXTEDIT_INSERTIMAGEWIDGET_H
 
-#include "kpimtextedit_export.h"
-
 #include <QUrl>
 
 #include <QWidget>
@@ -29,7 +27,7 @@
 namespace KPIMTextEdit {
 class InsertImageWidgetPrivate;
 
-class KPIMTEXTEDIT_EXPORT InsertImageWidget : public QWidget
+class InsertImageWidget : public QWidget
 {
     Q_OBJECT
 public:
