@@ -26,7 +26,10 @@
 
 namespace KPIMTextEdit {
 class SelectSpecialCharDialogPrivate;
-
+/**
+ * @brief The SelectSpecialCharDialog class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KPIMTEXTEDIT_EXPORT SelectSpecialCharDialog : public QDialog
 {
     Q_OBJECT
@@ -52,6 +55,8 @@ Q_SIGNALS:
 private:
     SelectSpecialCharDialogPrivate *const d;
     friend class SelectSpecialCharDialogPrivate;
+    void readConfig();
+    void writeConfig();
 };
 }
 
