@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -41,8 +41,11 @@ public:
     void setFoundMatch(bool match);
 
     bool isRegularExpression() const;
-
+#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
     Q_REQUIRED_RESULT QRegExp searchRegExp() const;
+#else
+    Q_REQUIRED_RESULT QRegularExpression searchRegExp() const;
+#endif
 
     Q_REQUIRED_RESULT QString searchText() const;
 
