@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -47,7 +47,7 @@ TextGoToLineWidget::TextGoToLineWidget(QWidget *parent)
     , d(new KPIMTextEdit::TextGoToLineWidgetPrivate)
 {
     QHBoxLayout *hbox = new QHBoxLayout(this);
-    hbox->setMargin(2);
+    hbox->setContentsMargins(2, 2, 2, 2);
     QToolButton *closeBtn = new QToolButton(this);
     closeBtn->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
     closeBtn->setIconSize(QSize(16, 16));
