@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,6 +25,7 @@
 #include <KColorScheme>
 
 #include <QTextEdit>
+#include <QRegularExpression>
 
 using namespace KPIMTextEdit;
 class KPIMTextEdit::RichTextEditFindBarPrivate
@@ -72,6 +73,7 @@ bool RichTextEditFindBar::searchInDocument(const QString &text, QTextDocument::F
     return found;
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
 bool RichTextEditFindBar::searchInDocument(const QRegExp &regExp, QTextDocument::FindFlags searchOptions)
 {
     const bool found = d->mView->find(regExp, searchOptions);
@@ -79,6 +81,16 @@ bool RichTextEditFindBar::searchInDocument(const QRegExp &regExp, QTextDocument:
     return found;
 }
 
+#else
+bool RichTextEditFindBar::searchInDocument(const QRegularExpression &regExp, QTextDocument::FindFlags searchOptions)
+{
+    const bool found = d->mView->find(regExp, searchOptions);
+    mFindWidget->setFoundMatch(found);
+    return found;
+}
+
+#endif
+
 void RichTextEditFindBar::autoSearchMoveCursor()
 {
     QTextCursor cursor = d->mView->textCursor();
