@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,14 +21,15 @@
 #define TEXTTOSPEECH_H
 
 #include "kpimtextedit_export.h"
-#include "config-kpimtextedit.h"
 #include <QObject>
 
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
 class QTextToSpeech;
-#endif
 
 namespace KPIMTextEdit {
+/**
+ * @brief The TextToSpeech class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KPIMTEXTEDIT_EXPORT TextToSpeech : public QObject
 {
     Q_OBJECT
@@ -46,7 +47,7 @@ public:
         BackendError
     };
 
-    int volume() const;
+    double volume() const;
     QVector<QLocale> availableLocales() const;
     QStringList availableEngines() const;
     QStringList availableVoices() const;
@@ -62,7 +63,7 @@ public Q_SLOTS:
 
     void setRate(double rate);
     void setPitch(double pitch);
-    void setVolume(int volume);
+    void setVolume(double volume);
     void setLocale(const QLocale &locale) const;
 
 Q_SIGNALS:
@@ -73,10 +74,8 @@ private:
     explicit TextToSpeech(QObject *parent = nullptr);
     friend class TextToSpeechPrivate;
 
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     QString mDefaultEngine;
     QTextToSpeech *mTextToSpeech = nullptr;
-#endif
 };
 }
 
