@@ -26,6 +26,10 @@
 namespace KPIMTextEdit {
 class AbstractTextToSpeechInterface;
 class TextToSpeechWidgetPrivate;
+/**
+ * @brief The TextToSpeechWidget class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KPIMTEXTEDIT_EXPORT TextToSpeechWidget : public QWidget
 {
     Q_OBJECT
@@ -57,6 +61,7 @@ Q_SIGNALS:
 
 private:
     void slotVolumeChanged(int value);
+    void slotCloseTextToSpeechWidget();
     void slotConfigure();
     TextToSpeechWidgetPrivate *const d;
 };
